@@ -3,7 +3,7 @@ import * as yup from 'yup';
 export interface Setting<T = any> {
   name?: string;
   description?: string;
-  type: yup.SchemaOf<T>;
+  type: yup.Schema<T>;
   unit?: string;
   highRisk?: boolean;
   defaultValue: T;
